/**
 * apeman task to generate certifications.
 * @memberof module:apeman-task-crt/lib
 * @function define
 * @param {string|function} name - Names to generate.
 * @param {object} [options] - Optional settings.
 * @param {string} options.out - Output directory path.
 * @returns {function} - Defined task function.
 */

'use strict'

const co = require('co')
const arrayreduce = require('arrayreduce')
const apemanCrt = require('apeman-crt')

/** @lends define */
function define (names, options = {}) {
  let concatArray = arrayreduce.arrayConcat()

  /**
   * Defined task.
   * @function task
   * @param {object} context - Apeman task context.
   * @returns {Promise}
   */
  function task (context) {
    let { logger } = context

    names = [].concat(names).map((name) => {
      if (typeof name === 'function') {
        return name()
      }
      return name
    }).reduce(concatArray, [])

    return co(function * () {

      let out = options.out || process.cwd()
      let force = options.force
      for (let name of names) {
        yield apemanCrt(name, {
          configuration: options.configuration || context.apemanfile.$cwd,
          out,
          force,
          self: true
        })
      }
    })
  }

  // Description of this task.
  task.$desc = 'Generate certifications.'
  return task
}

module.exports = define
